@@ -20,7 +20,7 @@ from lesscode.db.connection_info import ConnectionInfo
 from lesscode.db.es.es_pool import EsPool
 from lesscode.db.es.es_request import EsRequest
 from lesscode.db.page import Page
-from lesscode.utils.EsUtil import format_es_param_result,  es_mapping2dict
+from lesscode.utils.EsUtil import format_es_param_result, es_mapping2dict
 from lesscode.utils.common import dict2single_dict
 from lesscode.utils.encryption_algorithm import AES
 
@@ -191,9 +191,9 @@ class EsHelper:
             "route_key": route_key,
         }, find_condition=params)
         logging.info("进程{}，路由{},查询时间{}".format(os.getpid(), route_key, datetime.now() - start_time))
-
         if "error" in list(res.keys()):
             logging.info(res)
+            return None
         return res["hits"]
 
     def correction_param(self, param, mappings):
@@ -299,13 +299,15 @@ class EsHelper:
                                          size=size,
                                          offset=offset,
                                          track_total_hits=track_total_hits)
-
         result_list = []
-        for r in res["hits"]:
-            result_list.append(
-                format_es_param_result(r, param_list, is_need_decrypt_oralce, is_need_es_score, route_key))
+        data_count = 0
+        if res:
+            for r in res["hits"]:
+                result_list.append(
+                    format_es_param_result(r, param_list, is_need_decrypt_oralce, is_need_es_score, route_key))
+            data_count = res["total"]["value"]
         result_dict = {
-            "data_count": res["total"]["value"],
+            "data_count": data_count,
             "data_list": result_list
         }
         return result_dict
@@ -398,6 +400,13 @@ class EsHelper:
         }, find_condition=params)
         if "error" in list(res.keys()):
             logging.info(res)
+            return {
+                "aggregations": {
+                    "NAME": {
+                        "buckets": []
+                    }
+                }
+            }
         return res
 
     def sync_delete_one(self, route_key, id):
@@ -472,7 +481,7 @@ class EsHelper:
     def correction_body(self, route_key, body):
         try:
             es_mapping_res = self.sync_es_mapping(route_key)
-            es_mapping = es_mapping_res.get(route_key, {}).get("mappings", {})
+            es_mapping = es_mapping_res.get(route_key, {}).get("mappings", {}).get("properties", {})
             self.correction_param(body, es_mapping)
         except Exception as e:
             traceback.format_exc()
