@@ -132,9 +132,9 @@ class EsRequest:
         return self.replace_url_kwargs("http://{host}{port}{path}",
                                        {"host": host, "port": port, "path": path})
 
-    def format_es_field_mapping_url(self, field, host=None, port=None, route_key=None):
-        return self.replace_url_kwargs("http://{host}{port}/{route_key}/_mapping/field/{field}",
-                                       {"host": host, "port": port, "route_key": route_key, "field": field})
+    def format_es_mapping_url(self, host=None, port=None, route_key=None):
+        return self.replace_url_kwargs("http://{host}{port}/{route_key}/_mapping",
+                                       {"host": host, "port": port, "route_key": route_key})
 
     def replace_url_kwargs(self, replace_url, replace_kwargs):
         if not replace_kwargs["host"]:
