@@ -22,15 +22,9 @@ class SqlAlchemyHelper:
     def make_session(self, **kwargs):
         db_session = scoped_session(sessionmaker(bind=self.pool, **kwargs))
         session = db_session()
-        try:
-            yield session
-            session.commit()
-        except Exception as e:
-            logging.error(e.args)
-            logging.error(traceback.format_exc())
-            session.rollback()
-        finally:
-            session.close()
+        yield session
+        session.commit()
+        session.close()
 
 
 def alchemy_default_to_dict(params, data, repetition=False):
