@@ -20,6 +20,7 @@ from bson import ObjectId
 from tornado import httputil
 from tornado.escape import utf8
 from tornado.ioloop import IOLoop
+from tornado.options import options
 from tornado.web import RequestHandler, Application
 
 from lesscode.task.task_helper import TaskHelper
@@ -234,10 +235,11 @@ class BaseHandler(RequestHandler):
                 self.end_time = int(round(time.time() * 1000))
                 self.set_header("Api-Time", f"{self.end_time - self.start_time}ms")
                 self.process_response(data)
-                task_id = uuid.uuid1().hex
-                TaskHelper.add_job(es_record_log, id=task_id, name=task_id,
-                                   kwargs={"request": self.request, "message": "", "level": "info",
-                                           "status_code": "00000", "task_id": task_id})
+                if options.scheduler_config.get("enable"):
+                    task_id = uuid.uuid1().hex
+                    TaskHelper.add_job(es_record_log, id=task_id, name=task_id,
+                                       kwargs={"request": self.request, "message": "", "level": "info",
+                                               "status_code": "00000", "task_id": task_id})
             except Exception as e:
                 self.process_exception(e)
 
@@ -278,10 +280,11 @@ class BaseHandler(RequestHandler):
         :param kwargs:
         :return:
         """
-        task_id = uuid.uuid1().hex
-        TaskHelper.add_job(es_record_log, id=task_id, name=task_id,
-                           kwargs={"request": self.request, "message": traceback.format_exc(), "level": "error",
-                                   "status_code": status_code, "task_id": task_id})
+        if options.scheduler_config.get("enable"):
+            task_id = uuid.uuid1().hex
+            TaskHelper.add_job(es_record_log, id=task_id, name=task_id,
+                               kwargs={"request": self.request, "message": traceback.format_exc(), "level": "error",
+                                       "status_code": status_code, "task_id": task_id})
         error = kwargs["exc_info"]
         if isinstance(error[1], BusinessException):
             self.set_status(200)
