@@ -24,8 +24,10 @@ from lesscode.extend_handlers.not_found_handler import NotFoundHandler
 from lesscode.web.router_mapping import RouterMapping
 import platform
 
-define("application_name", default=f"{os.path.split(os.path.dirname(sys.argv[0]))[-1]}", type=str, help="配置文件")
-define("project_name", default=f"{os.path.split(os.path.dirname(sys.argv[0]))[-1]}", type=str, help="配置文件")
+define("application_name", default=f"{os.path.split(os.path.abspath(os.path.dirname(sys.argv[0])))[-1]}", type=str,
+       help="应用名称")
+define("project_name", default=f"{os.path.split(os.path.abspath(os.path.dirname(sys.argv[0])))[-1]}", type=str,
+       help="项目名称")
 define("application_path", default=f"{os.path.abspath(os.path.dirname(sys.argv[0]))}", type=str, help="应用运行根路径")
 define("cookie_secret", default="hRHQlJoUQIiNai2MLV9fQV3YDpxWrUHQp/jnfF9riQk=", type=str, help="cookie 秘钥 ")
 define("static_path", default=os.path.join(f"{os.path.abspath(os.path.dirname(sys.argv[0]))}", "static"), type=str,
